==> winnie-0.1.46.tgz: package/model/classes.js <==
'use strict';

var BoxField = require('kenga/box-field');
var Container = require('kenga/container');
var Label = require('kenga-labels/label');
var Button = require('kenga-buttons/button');
var CheckBox = require('kenga-buttons/check-box');
var RadioButton = require('kenga-buttons/radio-button');
var Box = require('kenga-containers/box-pane');
var HorizontalBox = require('kenga-containers/horizontal-box-pane');
var VerticalBox = require('kenga-containers/vertical-box-pane');
var SplitPane = require('kenga-containers/split-pane');
var CardPane = require('kenga-containers/card-pane');
var FlowPane = require('kenga-containers/flow-pane');
var GridPane = require('kenga-containers/grid-pane');
var HolyGrailPane = require('kenga-containers/holy-grail-pane');
var ScrollPane = require('kenga-containers/scroll-pane');
var Anchors = require('kenga-containers/anchors-pane');
var TabbedPane = require('kenga-containers/tabbed-pane');
var Toolbar = require('kenga-containers/tool-bar');
var Menu = require('kenga-menu/menu');
var MenuBar = require('kenga-menu/menu-bar');
var MenuItem = require('kenga-menu/menu-item');
var DataGrid = require('kenga-grid/grid');
var ColumnNode = require('kenga-grid/columns/column-node');
var MenuSeparator = require('kenga-menu/menu-separator');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var BoxField__default = /*#__PURE__*/_interopDefaultLegacy(BoxField);
var Container__default = /*#__PURE__*/_interopDefaultLegacy(Container);
var Label__default = /*#__PURE__*/_interopDefaultLegacy(Label);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var CheckBox__default = /*#__PURE__*/_interopDefaultLegacy(CheckBox);
var RadioButton__default = /*#__PURE__*/_interopDefaultLegacy(RadioButton);
var Box__default = /*#__PURE__*/_interopDefaultLegacy(Box);
var HorizontalBox__default = /*#__PURE__*/_interopDefaultLegacy(HorizontalBox);
var VerticalBox__default = /*#__PURE__*/_interopDefaultLegacy(VerticalBox);
var SplitPane__default = /*#__PURE__*/_interopDefaultLegacy(SplitPane);
var CardPane__default = /*#__PURE__*/_interopDefaultLegacy(CardPane);
var FlowPane__default = /*#__PURE__*/_interopDefaultLegacy(FlowPane);
var GridPane__default = /*#__PURE__*/_interopDefaultLegacy(GridPane);
var HolyGrailPane__default = /*#__PURE__*/_interopDefaultLegacy(HolyGrailPane);
var ScrollPane__default = /*#__PURE__*/_interopDefaultLegacy(ScrollPane);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var TabbedPane__default = /*#__PURE__*/_interopDefaultLegacy(TabbedPane);
var Toolbar__default = /*#__PURE__*/_interopDefaultLegacy(Toolbar);
var Menu__default = /*#__PURE__*/_interopDefaultLegacy(Menu);
var MenuBar__default = /*#__PURE__*/_interopDefaultLegacy(MenuBar);
var MenuItem__default = /*#__PURE__*/_interopDefaultLegacy(MenuItem);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);
var MenuSeparator__default = /*#__PURE__*/_interopDefaultLegacy(MenuSeparator);

/**
 * This transformation is necessary due to obfuscation of constructors names.
 * @param {Widget} instance
 * @returns {String}
 */

function constructorName(instance) {
  if (instance instanceof Toolbar__default['default']) {
    return 'ToolBar';
  } else if (instance instanceof HolyGrailPane__default['default']) {
    return 'HolyGrailPane';
  } else if (instance instanceof Box__default['default']) {
    return 'BoxPane';
  } else if (instance instanceof HorizontalBox__default['default']) {
    return 'HBox';
  } else if (instance instanceof VerticalBox__default['default']) {
    return 'VBox';
  } else if (instance instanceof Anchors__default['default']) {
    return 'AnchorsPane';
  } else if (instance instanceof FlowPane__default['default']) {
    return 'FlowPane';
  } else if (instance instanceof ScrollPane__default['default']) {
    return 'ScrollPane';
  } else if (instance instanceof SplitPane__default['default']) {
    return 'SplitPane';
  } else if (instance instanceof TabbedPane__default['default']) {
    return 'TabbedPane';
  } else if (instance instanceof CardPane__default['default']) {
    return 'CardPane';
  } else if (instance instanceof GridPane__default['default']) {
    return 'Cells';
  } else if (instance instanceof Menu__default['default']) {
    return 'Menu';
  } else if (instance instanceof MenuBar__default['default']) {
    return 'MenuBar';
  } else if (instance instanceof Container__default['default']) {
    return 'Container';
  } else if (instance instanceof BoxField__default['default']) {
    return 'Field';
  } else if (instance instanceof Label__default['default']) {
    return 'Label';
  } else if (instance instanceof Button__default['default']) {
    return 'Button';
  } else if (instance instanceof CheckBox__default['default']) {
    return 'CheckBox';
  } else if (instance instanceof RadioButton__default['default']) {
    return 'RadioButton';
  } else if (instance instanceof MenuItem__default['default']) {
    return 'MenuItem';
  } else if (instance instanceof MenuSeparator__default['default']) {
    return 'MenuSeparator';
  } else if (instance instanceof DataGrid__default['default']) {
    return 'DataGrid';
  } else if (instance instanceof ColumnNode__default['default']) {
    return 'Column';
  } else {
    return 'Widget';
  }
}

module.exports = constructorName;

==> winnie-0.1.51.tgz: package/model/classes.js <==
'use strict';

var BoxField = require('kenga/box-field');
var Container = require('kenga/container');
var Label = require('kenga-labels/label');
var Button = require('kenga-buttons/button');
var CheckBox = require('kenga-buttons/check-box');
var RadioButton = require('kenga-buttons/radio-button');
var Box = require('kenga-containers/box-pane');
var HorizontalBox = require('kenga-containers/horizontal-box-pane');
var VerticalBox = require('kenga-containers/vertical-box-pane');
var SplitPane = require('kenga-containers/split-pane');
var CardsPane = require('kenga-containers/card-pane');
var FlowPane = require('kenga-containers/flow-pane');
var GridPane = require('kenga-containers/grid-pane');
var HolyGrailPane = require('kenga-containers/holy-grail-pane');
var ScrollPane = require('kenga-containers/scroll-pane');
var Anchors = require('kenga-containers/anchors-pane');
var TabbedPane = require('kenga-containers/tabbed-pane');
var Toolbar = require('kenga-containers/tool-bar');
var Menu = require('kenga-menu/menu');
var MenuBar = require('kenga-menu/menu-bar');
var MenuItem = require('kenga-menu/menu-item');
var DataGrid = require('kenga-grid/grid');
var ColumnNode = require('kenga-grid/columns/column-node');
var MenuSeparator = require('kenga-menu/menu-separator');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var BoxField__default = /*#__PURE__*/_interopDefaultLegacy(BoxField);
var Container__default = /*#__PURE__*/_interopDefaultLegacy(Container);
var Label__default = /*#__PURE__*/_interopDefaultLegacy(Label);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var CheckBox__default = /*#__PURE__*/_interopDefaultLegacy(CheckBox);
var RadioButton__default = /*#__PURE__*/_interopDefaultLegacy(RadioButton);
var Box__default = /*#__PURE__*/_interopDefaultLegacy(Box);
var HorizontalBox__default = /*#__PURE__*/_interopDefaultLegacy(HorizontalBox);
var VerticalBox__default = /*#__PURE__*/_interopDefaultLegacy(VerticalBox);
var SplitPane__default = /*#__PURE__*/_interopDefaultLegacy(SplitPane);
var CardsPane__default = /*#__PURE__*/_interopDefaultLegacy(CardsPane);
var FlowPane__default = /*#__PURE__*/_interopDefaultLegacy(FlowPane);
var GridPane__default = /*#__PURE__*/_interopDefaultLegacy(GridPane);
var HolyGrailPane__default = /*#__PURE__*/_interopDefaultLegacy(HolyGrailPane);
var ScrollPane__default = /*#__PURE__*/_interopDefaultLegacy(ScrollPane);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var TabbedPane__default = /*#__PURE__*/_interopDefaultLegacy(TabbedPane);
var Toolbar__default = /*#__PURE__*/_interopDefaultLegacy(Toolbar);
var Menu__default = /*#__PURE__*/_interopDefaultLegacy(Menu);
var MenuBar__default = /*#__PURE__*/_interopDefaultLegacy(MenuBar);
var MenuItem__default = /*#__PURE__*/_interopDefaultLegacy(MenuItem);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);
var ColumnNode__default = /*#__PURE__*/_interopDefaultLegacy(ColumnNode);
var MenuSeparator__default = /*#__PURE__*/_interopDefaultLegacy(MenuSeparator);

/**
 * This transformation is necessary due to obfuscation of constructors names.
 * @param {Widget} instance
 * @returns {String}
 */

function constructorName(instance) {
  if (instance instanceof Toolbar__default['default']) {
    return 'ToolBar';
  } else if (instance instanceof HolyGrailPane__default['default']) {
    return 'HolyGrailPane';
  } else if (instance instanceof Box__default['default']) {
    return 'BoxPane';
  } else if (instance instanceof HorizontalBox__default['default']) {
    return 'HBox';
  } else if (instance instanceof VerticalBox__default['default']) {
    return 'VBox';
  } else if (instance instanceof Anchors__default['default']) {
    return 'AnchorsPane';
  } else if (instance instanceof FlowPane__default['default']) {
    return 'FlowPane';
  } else if (instance instanceof ScrollPane__default['default']) {
    return 'ScrollPane';
  } else if (instance instanceof SplitPane__default['default']) {
    return 'SplitPane';
  } else if (instance instanceof TabbedPane__default['default']) {
    return 'TabbedPane';
  } else if (instance instanceof CardsPane__default['default']) {
    return 'CardPane';
  } else if (instance instanceof GridPane__default['default']) {
    return 'Cells';
  } else if (instance instanceof Menu__default['default']) {
    return 'Menu';
  } else if (instance instanceof MenuBar__default['default']) {
    return 'MenuBar';
  } else if (instance instanceof Container__default['default']) {
    return 'Container';
  } else if (instance instanceof BoxField__default['default']) {
    return 'Field';
  } else if (instance instanceof Label__default['default']) {
    return 'Label';
  } else if (instance instanceof Button__default['default']) {
    return 'Button';
  } else if (instance instanceof CheckBox__default['default']) {
    return 'CheckBox';
  } else if (instance instanceof RadioButton__default['default']) {
    return 'RadioButton';
  } else if (instance instanceof MenuItem__default['default']) {
    return 'MenuItem';
  } else if (instance instanceof MenuSeparator__default['default']) {
    return 'MenuSeparator';
  } else if (instance instanceof DataGrid__default['default']) {
    return 'DataGrid';
  } else if (instance instanceof ColumnNode__default['default']) {
    return 'Column';
  } else {
    return 'Widget';
  }
}

module.exports = constructorName;
